@@ -1,13 +1,28 @@
 from rest_framework.generics import ListCreateAPIView
+from rest_framework import serializers
 from .tasks import scrape
 from rest_framework.response import Response
 from bson.objectid import ObjectId
 from bson.json_util import dumps
+from drf_spectacular.utils import inline_serializer, extend_schema, extend_schema_view
 
 from .models import ListEntry, Person, List
 from .serializers import ListEntrySerializer
 
 
+@extend_schema_view(
+    create=extend_schema(
+        request=inline_serializer(
+            name="RequestSerializerLemmaResarch",
+            fields={
+                "gnd": serializers.ListField(child=serializers.URLField()),
+                "firstName": serializers.CharField(),
+                "lastName": serializers.CharField(),
+                "list": serializers.PrimaryKeyRelatedField(queryset=List.objects.all()),
+            },
+        )
+    )
+)
 class LemmaResearchView(ListCreateAPIView):
     """APIView to process scraping requests
 
