@@ -1,4 +1,6 @@
 from rest_framework import serializers
+from drf_spectacular.utils import extend_schema_field
+from drf_spectacular.types import OpenApiTypes
 
 from .models import ListEntry
 
@@ -9,16 +11,20 @@ class ListEntrySerializer(serializers.ModelSerializer):
     lastName = serializers.CharField(source="person.name")
     list = serializers.SerializerMethodField(method_name="get_list")
 
+    @extend_schema_field(OpenApiTypes.OBJECT)
     def get_list(self, object):
         res = {"id": object.list_id, "title": object.list.title}
         return res
 
+    @extend_schema_field(OpenApiTypes.OBJECT)
     def get_gnd(self, object):
         if object.person.uris is not None:
+            res = []
             for uri in object.person.uris:
                 if "d-nb.info" in uri:
-                    return uri
-        return "not specified"
+                    res.append(uri)
+            return res
+        return []
 
     class Meta:
         model = ListEntry
