@@ -238,12 +238,12 @@ def scrape(self, obj, user_id, list_title=None, scrapes=default_scrapes, wiki=Tr
     obj_scrape = []
     for idx, ent in enumerate(obj["lemmas"]):
         test_gnd = False
-        ent_dict = {"first_name": ent["firstName"], "name": ent["lastName"]}
+        ent_dict = {"first_name": ent["firstName"], "name": ent["lastName"], "uris": []}
         if "gnd" in ent.keys():
-            ent_dict["uris"] = [
-                f"https://d-nb.info/gnd/{ent['gnd']}/",
-            ]
-            test_gnd = True
+            for g in ent["gnd"]:
+                ent_dict["uris"].append(f"https://d-nb.info/gnd/{g}/")
+            if len(ent_dict["uris"]) == 1:
+                test_gnd = True
         list_entry_dict = dict()
         dict_user_cols = {}
         for k, v in ent.items():
@@ -264,7 +264,7 @@ def scrape(self, obj, user_id, list_title=None, scrapes=default_scrapes, wiki=Tr
         list_entry_dict["scrape"] = {"obv": [], "wikipedia": [], "wikidata": []}
         list_entry = ListEntry.objects.create(**list_entry_dict)
         if test_gnd:
-            obj_scrape.append((ent["gnd"], ent, pers, list_entry))
+            obj_scrape.append((ent["gnd"][0], ent, pers, list_entry))
     res = group(
         scr.s(
             entry[0],
